@@ -226,12 +226,24 @@ public abstract class Page implements Serializable {
 		return bypass.toArray( new PageBypassedDiv[0] );
 	}
 
+	private static PageHooker[] sort( PageHooker[] ph ) {
+		Tag[]	tag = new Tag[ph.length];
+		for ( int i = 0; i < ph.length; i++ ) {
+			tag[i] = (Tag)ph[i];
+		}
+		tag = Tag.sort( tag );
+		for ( int i = 0; i < ph.length; i++ ) {
+			ph[i] = (PageHooker)tag[i];
+		}
+		return ph;
+	}
+
 	/**
 	 * 保持している PageHooker を返します。
 	 * @return PageHookerの配列。無ければ 0 個の配列を返します。
 	 */
 	public PageHooker[] getPageHooker() {
-		return hook.toArray( new PageHooker[0] );
+		return sort( hook.toArray( new PageHooker[0] ) );
 	}
 
 	private void makeKey() {
@@ -1027,6 +1039,12 @@ public abstract class Page implements Serializable {
 	public void resetOnLoadScript() {
 		getOnloadTag().removeHTMLPart();
 		getOnloadTag().addHTMLPart( new paraselene.ajax.data.JavaScript() );
+		if ( getAjaxSupport() == Page.AjaxSupport.SERVER_PUSH ) {
+			StringBuilder	buf = new StringBuilder( "paraselene_comet_start('" );
+			buf = buf.append( getUniqueKey() );
+			buf = buf.append( "');" );
+			addOnLoadScript( buf.toString() );
+		}
 	}
 
 	/**
@@ -1150,7 +1168,7 @@ public abstract class Page implements Serializable {
 		if ( getMainTag() == null )	return;
 		firstOutput( req );
 		ajax_f = true;
-		if ( !safari_f && getAccessedMobile() == RequestParameter.Mobile.NO_MOBILE && getAccessedSearchEngine() == RequestParameter.SearchEngine.NO_SEARCHENGINE ) {
+		if ( getAccessedMobile() == RequestParameter.Mobile.NO_MOBILE && getAccessedSearchEngine() == RequestParameter.SearchEngine.NO_SEARCHENGINE ) {
 			AjaxSupport	ajax = getAjaxSupport();
 			Tag	head = getFirstTagByType( "head" );
 			Tag	body = getFirstTagByType( "body" );
@@ -1167,7 +1185,7 @@ public abstract class Page implements Serializable {
 					Tag	tag = new Tag( "link", true );
 					tag.setAttribute(
 						new Attribute( "rel", new Text( "stylesheet" ) ),
-						new Attribute( "href", new URIValue( "paraselene.css.na" ) ),
+						new Attribute( "href", new URIValue( "css/paraselene.css/paraselene.resource.na" ) ),
 						new Attribute( "type", new Text( "text/css" ) )
 					);
 					head.addHTMLPart( idx, tag );
@@ -1182,7 +1200,7 @@ public abstract class Page implements Serializable {
 				try {
 					script.setAttribute(
 						new Attribute( "type", "text/javascript" ),
-						new Attribute( "src", "paraselene.js.na" )
+						new Attribute( "src", "js/paraselene.js/paraselene.resource.na" )
 					);
 				}
 				catch( Exception e ) {
@@ -1191,6 +1209,7 @@ public abstract class Page implements Serializable {
 				head.addHTMLPart( script );
 
 				Tag[]	div = new Tag[] { new Tag( "div", false ), new Tag( "div", false ) };
+				root_id = div[0].makeID();
 				div[0].include( body, true );
 				Tag eclipse = new Tag( "div", false );
 				eclipse.setAttribute(
@@ -1209,11 +1228,20 @@ public abstract class Page implements Serializable {
 				);
 				body.removeHTMLPart();
 				body.addHTMLPart( div[0], div[1], getOnloadTag() );
+				resetOnLoadScript();
 			}
 			else	ajax_f = false;
 		}
 		else	ajax_f = false;
-		if ( getPopupType() != null )	ajax_f = true;
+		if ( getPopupType() != null ) {
+			ajax_f = true;
+			resetOnLoadScript();
+		}
+	}
+
+	private String	root_id;
+	public String getRootID() {
+		return root_id;
 	}
 
 	private static final String	AJAX_BLACK_ID = "paraseleneEclipse";
@@ -1224,11 +1252,11 @@ public abstract class Page implements Serializable {
 	private RequestParameter.Mobile			access_mobile;
 	private RequestParameter.SearchEngine	access_se;
 	private Tag	onload_tag = null;
-	private boolean safari_f = false;
 
 	private Tag getOnloadTag() {
 		if ( onload_tag != null )	return onload_tag;
 		onload_tag = Tag.makeScript();
+		onload_tag.setModifyEnable( false );
 		return onload_tag;
 	}
 
@@ -1251,12 +1279,6 @@ public abstract class Page implements Serializable {
 		if ( req != null ) {
 			access_mobile = req.judgeMobile();
 			access_se = req.judgeSearchEngine();
-/***
-			String[]	ua = req.getHeader( "User-Agent" );
-			if ( ua != null ) {
-				safari_f = ( ua[0].indexOf( "Chrome" ) == -1 && ua[0].indexOf( "Safari" ) >= 0 );
-			}
-***/
 		}
 	}
 
@@ -1332,5 +1354,21 @@ public abstract class Page implements Serializable {
 		if ( str.isEmpty() )	str = "　";
 		return new HTMLPart[]{ new Text( str ) };
 	}
+
+	private PageServerInformation	server_info = null;
+	/**
+	 * サーバー情報の取得。
+	 * @return サーバー情報。
+	 */
+	public PageServerInformation getPageServerInformation() {
+		return server_info;
+	}
+	/**
+	 * サーバー情報の設定。
+	 * @param psi サーバー情報。
+	 */
+	public void setPageServerInformation( PageServerInformation psi ) {
+		server_info = psi;
+	}
 }
 
