@@ -14,15 +14,15 @@ import java.util.zip.*;
 import java.util.jar.*;
 
 /**
- * Paraseleneのバージョン番号。
+ * Paraseleneのバージョン情報。
  */
 public class Version {
 	private Version(){}
 	/**
 	 * Paraseleneのバージョン番号を表す文字列。
-	 * 2.2
+	 * 2.2.1
 	 */
-	public static final String VERSION = "2.2";
+	public static final String VERSION = "2.2.1";
 	private static final String	SITE = " (http://paraselene.sourceforge.jp/)";
 	private static final String	TITLE = "Paraselene2 " + VERSION + SITE;
 	private static final String[] CLASS_PATH = new String[] {
@@ -32,6 +32,21 @@ public class Version {
 	};
 	private static final File JAR_PATH = seekJar();
 
+	/**
+	 * バージョン番号の取得。
+	 * @return バージョンが 2.3.4 であれば、
+	 * new int[]{ 2, 3, 4 }
+	 * のような配列を返します。
+	 */
+	public static int[] getVersion() {
+		String[]	ver = VERSION.split( "\\." );
+		int[]	ret = new int[ver.length];
+		for ( int i = 0; i < ver.length; i++ ) {
+			ret[i] = Integer.parseInt( ver[i] );
+		}
+		return ret;
+	}
+
 	/**
 	 * Paraseleneのアプリタイトル文字列。
 	 * @return アプリタイトル。
