@@ -12,9 +12,12 @@ import java.io.*;
 /**
  * 画面遷移履歴セット。スレッドセーフです。
  */
-class HistorySet implements Serializable {
+public class HistorySet implements Serializable {
 	private static final long serialVersionUID = 2L;
-	static final int	ROOT = 0;
+	/**
+	 * ルート履歴キー。
+	 */
+	public static final int	ROOT = 0;
 	static final int	RAND = 0x7fffffff;
 	private HashMap<String,Integer>		set_no = new HashMap<String,Integer>();
 	private HashMap<Integer,History>	hist = new HashMap<Integer,History>();
@@ -31,7 +34,12 @@ class HistorySet implements Serializable {
 		return key;
 	}
 
-	synchronized History get( int key ) {
+	/**
+	 * 履歴の取得。
+	 * @param key 履歴キー。
+	 * @return 履歴。
+	 */
+	public synchronized History get( int key ) {
 		return hist.get( key );
 	}
 
