@@ -6,10 +6,13 @@
  */
 package paraselene.supervisor;
 
+import java.io.*;
+
 /**
  * サーバー情報。
  */
-public class PageServerInformation implements ServerInformation {
+public class PageServerInformation implements ServerInformation, Serializable {
+	private static final long serialVersionUID = 2L;
 	private String	server;
 	private String	context;
 	private TransactionSequencer	seq;
