@@ -10,6 +10,7 @@ package paraselene.supervisor;
 import java.util.*;
 import java.io.*;
 import paraselene.*;
+import paraselene.supervisor.*;
 import paraselene.tag.*;
 import paraselene.ui.*;
 import paraselene.ajax.*;
@@ -18,6 +19,8 @@ import paraselene.ajax.data.*;
 class Child extends Thread implements DaemonChannel {
 	static volatile HashMap<String, Child>	name_space = new HashMap<String, Child>();
 
+	Date	start_dt;
+
 	volatile Page main_page = null;
 	volatile boolean call_input;
 	volatile RequestParameter request = null;
@@ -30,6 +33,8 @@ class Child extends Thread implements DaemonChannel {
 	volatile Daemon	daemon = null;
 	volatile String	daemon_name = null;
 	volatile ArrayList<History>	hist = null;
+	volatile Date	limit_dt = null;
+	volatile KilledByTimeoutException	kbt = null;
 
 	Child() {
 		setDaemon( true );
@@ -55,6 +60,10 @@ class Child extends Thread implements DaemonChannel {
 		}
 	}
 
+	public String getDaemonName() {
+		return daemon_name;
+	}
+
 	public void startDaemon( String name, Daemon daemon ) {
 		SandBox.startDaemon( name, daemon );
 	}
@@ -111,49 +120,54 @@ class Child extends Thread implements DaemonChannel {
 		}
 	}
 
-	private static final String	COMET = "paraselene_comet";
+	public Page[] getPageForUpdate( PageID ... id ) {
+		Page[]	page = getPageForUpdate();
+		ArrayList<Page>	ret = new ArrayList<Page>();
+		for ( int i = 0; i < page.length; i++ ) {
+			PageID	p = page[i].getID();
+			for ( int j = 0; j < id.length; j++ ) {
+				if ( id[j] == p ) {
+					ret.add( page[i] );
+					break;
+				}
+			}
+		}
+		return ret.toArray( new Page[0] );
+	}
 
-	public void commitPage() {
+	public void commitPage( DaemonForward ... fw ) {
 		if ( hist == null )	return;
 		synchronized( hist ) {
 			int	cnt = hist.size();
 			for ( int i = 0; i < cnt; i++ ) {
-				ArrayList<PostBack>	pb = new ArrayList<PostBack>();
 				History	h = hist.get( i );
 				Page[]	p = h.getBrowsingPage();
 				for ( int j = 0; j < p.length; j++ ) {
-					TagData[]	td = TagData.getTag( p[j] );
-					for ( int k = 0; k < td.length; k++ ) {
-						pb.add( new PostBack( td[k] ) );
+					for ( int fw_i = 0; fw_i < fw.length; fw_i++ ) {
+						if ( fw[fw_i].page == p[j] ) {
+							CometHolder	ch = new CometHolder( h, fw[fw_i].forward );
+							try {
+								Ajax.addComet( h.session_id, ch.getPostBack() );
+							}
+							catch( Exception e ) {
+								e.printStackTrace();
+							}
+						}
 					}
 				}
-				Ajax.add( h.session_id, COMET, (Serializable[])pb.toArray( new PostBack[0] ) );
 				h.unlock();
 			}
 		}
 	}
 
-	public void commitPage( PageID id ) {
-	}
-
-	public void commitPage( RequestParameter req, AjaxForward ... fw ) {
-	}
-
-	private static PageHooker[] sort( PageHooker[] src ) {
-		Tag[]	tag = new Tag[src.length];
-		for ( int i = 0; i < src.length; i++ ) {
-			tag[i] = (Tag)src[i];
-		}
-		tag = Tag.sort( tag );
-		for ( int i = 0; i < src.length; i++ ) {
-			src[i] = (PageHooker)tag[i];
-		}
-		return src;
+	public void delayTimeout() {
+		Date	now = new Date();
+		limit_dt = new Date( now.getTime() + SandBox.DAEMON_TIMEOUT );
 	}
 
 	private static Forward input( Page page, RequestParameter req, Forward fw ) throws Exception {
 		if ( page == null )	return fw;
-		PageHooker[]	hook = sort( page.getPageHooker() );
+		PageHooker[]	hook = page.getPageHooker();
 		for ( int i = 0; i < hook.length; i++ ) {
 			Forward	old = fw;
 			fw = hook[i].beforeInput( page, req, fw );
@@ -174,7 +188,7 @@ class Child extends Thread implements DaemonChannel {
 			div[i].setView( output( div[i].getBypassPage(), from, req ) );
 		}
 
-		PageHooker[]	hook = sort( page.getPageHooker() );
+		PageHooker[]	hook = page.getPageHooker();
 		for ( int i = 0; i < hook.length; i++ ) {
 			hook[i].afterOutput( from, old, req );
 		}
@@ -221,7 +235,10 @@ class Child extends Thread implements DaemonChannel {
 		catch( Throwable e ) {
 			th = e;
 		}
+		commitPage();
+		if ( kbt != null )	th = kbt;
 		try {
+			th.printStackTrace();
 			daemon.onDestroy( th );
 		}
 		finally {
@@ -278,6 +295,8 @@ public class SandBox extends Thread {
 	private static ArrayList<Child>	running = new ArrayList<Child>();
 	private static SandBox sand_box = null;
 
+	static final long	DAEMON_TIMEOUT = 1000 * 60 * 30;
+
 	private static Child getMyself() {
 		long	my_id = Thread.currentThread().getId();
 		synchronized( running ) {
@@ -332,6 +351,16 @@ public class SandBox extends Thread {
 		return child.call_input;
 	}
 
+	/**
+	 * このスレッドがデーモンであるか判定します。
+	 * @return true:デーモン、false:デーモンではない。
+	 */
+	public static boolean isCurrentDaemon() {
+		Child	child = getMyself();
+		if ( child == null )	return false;
+		return child.daemon != null;
+	}
+
 	private SandBox(){}
 
 	/**
@@ -483,6 +512,8 @@ public class SandBox extends Thread {
 			running.add( child );
 		}
 		synchronized( child ) {
+			child.start_dt = new Date();
+			child.limit_dt = new Date( child.start_dt.getTime() + SandBox.DAEMON_TIMEOUT );
 			child.notifyAll();
 		}
 		synchronized( sand_box ) {
@@ -514,6 +545,7 @@ public class SandBox extends Thread {
 	 * 既に同名処理があれば、このインスタンスは破棄されます。
 	 */
 	public static void startDaemon( String name, Daemon daemon ) {
+		ChildKiller.start( running );
 		History[]	hist = getCurrentHistory();
 		if ( hist == null )	return;
 		Child	child = null;
@@ -522,6 +554,7 @@ public class SandBox extends Thread {
 			if ( child == null ) {
 				child = getChild();
 				child.daemon = daemon;
+				child.hist = new ArrayList<History>();
 				if ( name != null ) {
 					child.daemon_name = name;
 					Child.name_space.put( name, child );
@@ -576,6 +609,17 @@ public class SandBox extends Thread {
 		return child.daemon.post( obj );
 	}
 
+	/**
+	 * バックグラウンド処理が存在しているか確認します。
+	 * @param name スレッド名。
+	 * @return true:存在している、false:存在しない。
+	 */
+	public static boolean isAliveDaemon( String name ) {
+		synchronized( Child.name_space ) {
+			return Child.name_space.get( name ) != null;
+		}
+	}
+
 	static void removeChild( Child child ) {
 		synchronized( running ) {
 			running.remove( child );
@@ -591,24 +635,7 @@ public class SandBox extends Thread {
 			if ( child.th != null )	throw child.th;
 			return;
 		}
-		ArrayList<StackTraceElement[]>	list = new ArrayList<StackTraceElement[]>();
-		StackTraceElement[]	crt = null;
-		synchronized( running ) {
-			int	cnt = running.size();
-			for ( int i = 0; i < cnt; i++ ) {
-				Child	c = running.get( i );
-				if ( c == child ) {
-					crt = c.getStackTrace();
-					continue;
-				}
-				list.add( c.getStackTrace() );
-			}
-		}
-		child.stop();
-		synchronized( running ) {
-			running.remove( child );
-		}
-		throw new KilledByTimeoutException( crt, list );
+		throw ChildKiller.kill( child );
 	}
 
 	static Forward input( Page action, RequestParameter req, Forward fw )
