@@ -96,6 +96,7 @@ public class Form extends Tag implements PageHooker {
 			page_ukey
 		};
 		addHTMLPart( id );
+		setAttribute( "method", "POST" );
 		fixed_f = true;
 	}
 
@@ -115,6 +116,11 @@ public class Form extends Tag implements PageHooker {
 	}
 
 	public void afterOutput( Page from, Page to, RequestParameter req ) throws Exception {
+		commitDaemon();
+		page_ukey.setValueString( getAssignedPage().getUniqueKey() );
+	}
+
+	public void commitDaemon() {
 		StringBuilder	buf = new StringBuilder( "function(ev){" );
 		buf = buf.append( "if(paraselene_form_kill)return;" );
 		buf = buf.append( "if(!paraselene_agency_form(paraselene_get_id('" );
@@ -123,7 +129,6 @@ public class Form extends Tag implements PageHooker {
 		buf = buf.append( getAssignedPage().getUniqueKey() );
 		buf = buf.append( "'))paraselene_kill_event(ev);}" );
 		setAnonymousEventHandler( "submit", buf.toString() );
-		page_ukey.setValueString( getAssignedPage().getUniqueKey() );
 	}
 
 	protected Tag newReplica() {
