@@ -407,6 +407,13 @@ public class Table extends Tag {
 		}
 	}
 
+	/**
+	 * 行の削除。全ての行を削除します。
+	 */
+	public void removeLine() {
+		removeLine( 0, -1 );
+	}
+
 	/**
 	 * 行の複製作成。指定行の複製インスタンスを返します。<br>
 	 * 行番号が0未満または最大行数を超える場合はnullを返します。
