@@ -32,5 +32,10 @@ public interface PageHooker {
 	 */
 	void afterOutput( Page from, Page to, RequestParameter req ) throws Exception;
 
+	/**
+	 * バックグラウンド処理がページ更新する時に呼ばれます。<br>
+	 * JavaScript の登録が必要であれば、ここで行う必要があります。
+	 */
+	void commitDaemon();
 }
 
